pub struct ConnectionLine {
pub segments: Vec<Segment>,
pub from_box: Option<usize>,
pub to_box: Option<usize>,
}Expand description
An L-shaped or multi-segment connection line (e.g., between boxes).
Fields
segments: Vec<Segment>Segments that make up this connection line
from_box: Option<usize>Index of the box this line originates from (if any)
to_box: Option<usize>Index of the box this line connects to (if any)